==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/audio/input/input.h <==
/*
 *  Copyright (C) 2006-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef INPUT_H
#define INPUT_H

#include "inputTypes.h"

#include <fx.h>

#include "metaData.h"

/**
 * interface class for input config
*/
class inputConfig {
public:
	/// Open config dialog
	virtual void config(FXPacker* win) =0;

	/// Get filetype icon
	virtual FXIcon* icon() const =0;

	virtual void loadSettings() =0;

	virtual void saveSettings() =0;
};

/**
 * interface class for input backends
*/
class input : public inputConfig {
public:
	virtual ~input() {};

	/// Get supported extensions
	virtual FXString ext() const =0;

	/// Get song info
	virtual const metaData* getMetaData() const =0;

	/// Get song duration
	virtual const unsigned int time() const =0;

	/// Get samplerate
	virtual const unsigned int samplerate() const =0;

	/// Get channels
	virtual const unsigned int channels() const =0;

	/// Get precision
	virtual const sample_t precision() const =0;

	/// Get fractional scale for fixed point types
	virtual const unsigned int fract() const =0;

	/// Open file
	virtual bool open(const FXString& fileName) =0;

	/// Close file
	virtual void close() =0;

	/// Rewind to start
	virtual const bool rewind() =0;

	/// Callback function
	virtual size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds) =0;

	/// Song is loaded
	virtual const char* songLoaded() const =0;

	/// Get number of subtunes
	virtual unsigned int subtunes() const =0;

	/// Get current subtune
	virtual unsigned int subtune() const =0;

	/// Change subtune
	virtual bool subtune(const unsigned int i) =0;

	/// Gapless support
	virtual const bool gapless() =0;

	/// Get Music directory
	virtual const FXString getMusicDir(void) =0;
};


#endif

==> fap-0.9.0pre1.tar.bz2: fap-0.9.0pre1/src/audio/input/input.h <==
/*
 *  Copyright (C) 2006-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef INPUT_H
#define INPUT_H

#include "inputTypes.h"

#include <fx.h>

#include "metaData.h"

/**
 * interface class for input config
*/
class inputConfig {
public:
	/// Open config dialog
	virtual void config(FXPacker* win) =0;

	/// Get filetype icon
	virtual FXIcon* icon() const =0;

	virtual void loadSettings() =0;

	virtual void saveSettings() =0;
};

/**
 * interface class for input backends
*/
class input : public inputConfig {
public:
	virtual ~input() {};

	/// Get supported extensions
	virtual FXString ext() const =0;

	/// Get song info
	virtual const metaData* getMetaData() const =0;

	/// Get song duration
	virtual const unsigned int time() const =0;

	/// Get samplerate
	virtual const unsigned int samplerate() const =0;

	/// Get channels
	virtual const unsigned int channels() const =0;

	/// Get precision
	virtual const sample_t precision() const =0;

	/// Get fractional scale for fixed point types
	virtual const unsigned int fract() const =0;

	/// Open file
	virtual bool open(const FXString& fileName) =0;

	/// Close file
	virtual void close() =0;

	/// Seek specified position
	virtual const bool seek(const int pos) =0;

	/// Callback function
	virtual size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds) =0;

	/// Song is loaded
	virtual const char* songLoaded() const =0;

	/// Get number of subtunes
	virtual unsigned int subtunes() const =0;

	/// Get current subtune
	virtual unsigned int subtune() const =0;

	/// Change subtune
	virtual bool subtune(const unsigned int i) =0;

	/// Gapless support
	virtual const bool gapless() =0;

	/// Get Music directory
	virtual const FXString getMusicDir(void) =0;
};


#endif
